Method: OAuthenticator::ConfigMethods#timestamp_valid_past
- Defined in:
- lib/oauthenticator/config_methods.rb
#timestamp_valid_past ⇒ Integer
the number of seconds (integer) in the past for which the request is considered valid.
if the timestamp is more than this number of seconds less than the current clock time, then the request is considered invalid and the response is an error.
this should be large enough to allow for clock skew between your application's server and the requester's clock.
nonces older than Time.now - timestamp_valid_past may be discarded.
this method may remain unimplemented if #timestamp_valid_period is implemented.
49 50 51 |
# File 'lib/oauthenticator/config_methods.rb', line 49 def end |